@@ -26,6 +26,7 @@ except ImportError:
 class LogstashFormatter(logging.Formatter):
 
     # ----------------------------------------------------------------------
+    # pylint: disable=too-many-arguments
     def __init__(
             self,
             message_type='python-logstash',
@@ -33,13 +34,16 @@ class LogstashFormatter(logging.Formatter):
             fqdn=False,
             extra_prefix='extra',
             extra=None,
-            ensure_ascii=True):
+            ensure_ascii=True,
+            metadata=None,
+    ):
         super(LogstashFormatter, self).__init__()
         self._message_type = message_type
         self._tags = tags if tags is not None else []
         self._extra_prefix = extra_prefix
         self._extra = extra
         self._ensure_ascii = ensure_ascii
+        self._metadata = metadata
 
         self._interpreter = None
         self._interpreter_version = None
@@ -99,6 +103,8 @@ class LogstashFormatter(logging.Formatter):
             'program': self._program_name,
             'type': self._message_type,
         }
+        if self._metadata:
+            message['@metadata'] = self._metadata
         if self._tags:
             message['tags'] = self._tags
 
@@ -197,10 +203,7 @@ class LogstashFormatter(logging.Formatter):
 
     # ----------------------------------------------------------------------
     def _serialize(self, message):
-        if sys.version_info < (3, 0):
-            return json.dumps(message)
-        else:
-            return bytes(json.dumps(message, ensure_ascii=self._ensure_ascii), 'utf-8')
+        return json.dumps(message, ensure_ascii=self._ensure_ascii)
 
 
 class DjangoLogstashFormatter(LogstashFormatter):
